@@ -23,8 +23,8 @@ class /* NO_EXPORT */ KRomajiEdit : public KLineEdit
   Q_OBJECT
 
   public:
-    KRomajiEdit( QWidget *parent, const char *name );
-    ~KRomajiEdit();
+    KRomajiEdit( QWidget *parent);
+    ~KRomajiEdit() override;
 
   public Q_SLOTS:
     void setKana( QAction* );
